@@ -2,7 +2,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2018 Andrew Ziem
+# Copyright (C) 2008-2019 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -69,7 +69,7 @@ class CliCallback:
 
 def cleaners_list():
     """Yield each cleaner-option pair"""
-    register_cleaners()
+    list(register_cleaners())
     for key in sorted(backends):
         c_id = backends[key].get_id()
         for (o_id, o_name) in backends[key].get_options():
@@ -92,7 +92,7 @@ def preview_or_clean(operations, really_clean):
 
 def args_to_operations(args, preset):
     """Read arguments and return list of operations"""
-    register_cleaners()
+    list(register_cleaners())
     operations = {}
     if preset:
         # restore presets from the GUI
@@ -127,7 +127,8 @@ def args_to_operations(args, preset):
 def process_cmd_line():
     """Parse the command line and execute given commands."""
     # TRANSLATORS: This is the command line usage.  Don't translate
-    # %prog, but do translate usage, options, cleaner, and option.
+    # %prog, but do translate options, cleaner, and option.
+    # Don't translate and add "usage:" - it gets added by Python.
     # More information about the command line is here
     # https://www.bleachbit.org/documentation/command-line
     usage = _("usage: %prog [options] cleaner.option1 cleaner.option2")
@@ -139,7 +140,8 @@ def process_cmd_line():
                       # This is different than cleaning an arbitrary file, such as a
                       # spreadsheet on the desktop.
                       help=_("run cleaners to delete files and make other permanent changes"))
-    parser.add_option('--debug-log', help='log debug messages to file')
+    parser.add_option('--debug', help=_("set log level to verbose"), action="store_true")
+    parser.add_option('--debug-log', help=_("log debug messages to file"))
     parser.add_option("-s", "--shred", action="store_true",
                       help=_("shred specific files or folders"))
     parser.add_option("--sysinfo", action="store_true",
@@ -162,31 +164,44 @@ def process_cmd_line():
     if 'nt' == os.name:
         parser.add_option("--update-winapp2", action="store_true",
                           help=_("update winapp2.ini, if a new version is available"))
+    parser.add_option("-w", "--wipe-free-space", action="store_true",
+                      help=_("wipe free space in the given paths"))
     parser.add_option("-v", "--version", action="store_true",
                       help=_("output version information and exit"))
     parser.add_option('-o', '--overwrite', action='store_true',
                       help=_('overwrite files to hide contents'))
     (options, args) = parser.parse_args()
+
+    cmd_list = (options.list_cleaners, options.wipe_free_space,
+                options.preview, options.clean)
+    cmd_count = sum(x is True for x in cmd_list)
+    if cmd_count > 1:
+        logger.error(
+            _('Specify only one of these commands: --list-cleaners, --wipe-free-space, --preview, --clean'))
+        sys.exit(1)
+
     did_something = False
+    if options.debug:
+        # set in __init__ so it takes effect earlier
+        pass
     if options.debug_log:
         logger.addHandler(logging.FileHandler(options.debug_log))
-        logger.info('BleachBit version %s', APP_VERSION)
         logger.info(Diagnostic.diagnostic_info())
     if options.version:
         print("""
 BleachBit version %s
-Copyright (C) 2008-2018 Andrew Ziem.  All rights reserved.
+Copyright (C) 2008-2019 Andrew Ziem.  All rights reserved.
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.
 This is free software: you are free to change and redistribute it.
 There is NO WARRANTY, to the extent permitted by law.""" % APP_VERSION)
         sys.exit(0)
     if 'nt' == os.name and options.update_winapp2:
         from bleachbit import Update
-        logger.info("Checking online for updates to winapp2.ini")
+        logger.info(_("Checking online for updates to winapp2.ini"))
         Update.check_updates(False, True,
                              lambda x: sys.stdout.write("%s\n" % x),
                              lambda: None)
-        # updates can be combined with --list, --preview, --clean
+        # updates can be combined with --list-cleaners, --preview, --clean
         did_something = True
     if options.list_cleaners:
         list_cleaners()
@@ -195,32 +210,42 @@ There is NO WARRANTY, to the extent permitted by law.""" % APP_VERSION)
         from bleachbit.CleanerML import create_pot
         create_pot()
         sys.exit(0)
+    if options.wipe_free_space:
+        if len(args) < 1:
+            logger.error(_("No directories given for --wipe-free-space"))
+            sys.exit(1)
+        for wipe_path in args:
+            if not os.path.isdir(wipe_path):
+                logger.error(
+                    _("Path to wipe must be an existing directory: %s"), wipe_path)
+                sys.exit(1)
+        logger.info(_("Wiping free space can take a long time."))
+        for wipe_path in args:
+            logger.info('Wiping free space in path: %s', wipe_path)
+            import bleachbit.FileUtilities
+            for ret in bleachbit.FileUtilities.wipe_path(wipe_path):
+                pass
+        sys.exit(0)
     if options.preview or options.clean:
         operations = args_to_operations(args, options.preset)
         if not operations:
-            logger.error('No work to do. Specify options.')
+            logger.error(_("No work to do. Specify options."))
             sys.exit(1)
     if options.preview:
         preview_or_clean(operations, False)
         sys.exit(0)
     if options.overwrite:
         if not options.clean or options.shred:
-            logger.warning('--overwrite is intended only for use with --clean')
+            logger.warning(
+                _("--overwrite is intended only for use with --clean"))
         Options.options.set('shred', True, commit=False)
     if options.clean:
         preview_or_clean(operations, True)
         sys.exit(0)
     if options.gui:
-        import gtk
-        from bleachbit import GUI
-        shred_paths = args if options.shred else None
-        GUI.GUI(uac=not options.no_uac,
-                shred_paths=shred_paths, exit=options.exit)
-        gtk.main()
-        if options.exit:
-            # For automated testing of Windows build
-            print('Success')
-        sys.exit(0)
+        import bleachbit.GUI
+        app = bleachbit.GUI.Bleachbit(uac=not options.no_uac, shred_paths=args, auto_exit=options.exit)
+        sys.exit(app.run())
     if options.shred:
         # delete arbitrary files without GUI
         # create a temporary cleaner object
