@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2018 Andrew Ziem
+# Copyright (C) 2008-2019 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -22,7 +22,7 @@
 Command design pattern implementation for cleaning
 """
 
-from __future__ import absolute_import, print_function
+from __future__ import absolute_import
 
 from bleachbit import _
 from bleachbit import FileUtilities
@@ -119,6 +119,12 @@ class Function:
         except AssertionError:
             raise AssertionError('Expected MethodType but got %s' % type(func))
 
+    def __str__(self):
+        if self.path:
+            return 'Function: %s: %s' % (self.label, self.path)
+        else:
+            return 'Function: %s' % (self.label)
+
     def execute(self, really_delete):
 
         if self.path is not None and FileUtilities.whitelisted(self.path):
@@ -184,7 +190,7 @@ class Ini:
         self.parameter = parameter
 
     def __str__(self):
-        return 'Command to clean .ini path=%s, section=-%s, parameter=%s ' % \
+        return 'Command to clean .ini path=%s, section=%s, parameter=%s ' % \
             (self.path, self.section, self.parameter)
 
     def execute(self, really_delete):
@@ -218,7 +224,7 @@ class Json:
         self.path = path
         self.address = address
 
-    def __str(self):
+    def __str__(self):
         return 'Command to clean JSON file, path=%s, address=%s ' % \
             (self.path, self.address)
 
