@@ -27,6 +27,7 @@ from __future__ import absolute_import, print_function
 
 from tests import common
 from bleachbit.FileUtilities import *
+from bleachbit.General import run_external, sudo_mode
 from bleachbit.Options import options
 from bleachbit import expanduser, expandvars, logger
 
@@ -38,32 +39,37 @@ import unittest
 def test_ini_helper(self, execute):
     """Used to test .ini cleaning in TestAction and in TestFileUtilities"""
 
-    teststr = b'#Test\n[RecentsMRL]\nlist=C:\\Users\\me\\Videos\\movie.mpg,C:\\Users\\me\\movie2.mpg\n\n'
-    # create test file
-    filename = self.write_file('bleachbit-test-ini', teststr)
-    self.assertExists(filename)
-    size = os.path.getsize(filename)
-    self.assertEqual(len(teststr), size)
+    teststrings = [
+        b'#Test\n[RecentsMRL]\nlist=C:\\Users\\me\\Videos\\movie.mpg,C:\\Users\\me\\movie2.mpg\n\n',
+        u'#Test\n[RecentsMRL]\nlist=C:\\Юзъри\\me\\Videos\\movie.mpg,C:\\Users\\me\\movie2.mpg\n\n'.encode('ISO-8859-5')
+    ]
+    for teststr in teststrings:
 
-    # section does not exist
-    execute(filename, 'Recents', None)
-    self.assertEqual(len(teststr), os.path.getsize(filename))
+        # create test file
+        filename = self.write_file('bleachbit-test-ini', teststr)
+        self.assertExists(filename)
+        size = os.path.getsize(filename)
+        self.assertEqual(len(teststr), size)
 
-    # parameter does not exist
-    execute(filename, 'RecentsMRL', 'files')
-    self.assertEqual(len(teststr), os.path.getsize(filename))
+        # section does not exist
+        execute(filename, 'Recents', None)
+        self.assertEqual(len(teststr), os.path.getsize(filename))
 
-    # parameter does exist
-    execute(filename, 'RecentsMRL', 'list')
-    self.assertEqual(14, os.path.getsize(filename))
+        # parameter does not exist
+        execute(filename, 'RecentsMRL', 'files')
+        self.assertEqual(len(teststr), os.path.getsize(filename))
 
-    # section does exist
-    execute(filename, 'RecentsMRL', None)
-    self.assertEqual(0, os.path.getsize(filename))
+        # parameter does exist
+        execute(filename, 'RecentsMRL', 'list')
+        self.assertEqual(14, os.path.getsize(filename))
 
-    # clean up
-    delete(filename)
-    self.assertNotExists(filename)
+        # section does exist
+        execute(filename, 'RecentsMRL', None)
+        self.assertEqual(0, os.path.getsize(filename))
+
+        # clean up
+        delete(filename)
+        self.assertNotExists(filename)
 
 
 def test_json_helper(self, execute):
@@ -232,6 +238,17 @@ class FileUtilitiesTestCase(common.BleachbitTestCase):
         delete('does-not-exist', ignore_missing=True)
         self.assertRaises(OSError, delete, 'does-not-exist')
 
+    def test_delete_not_empty(self):
+        """Test for scenario directory is not empty"""
+        print('hello')
+        fn =os.path.join(self.tempdir, 'make-directory-not-empty')
+        common.touch_file(fn)
+        self.assertExists(fn)
+        self.assertExists(self.tempdir)
+        delete(self.tempdir, allow_shred=False)
+        self.assertExists(fn)
+        self.assertExists(self.tempdir)
+
     def delete_helper(self, shred):
         """Called by test_delete() with shred = False and = True"""
 
@@ -361,7 +378,31 @@ class FileUtilitiesTestCase(common.BleachbitTestCase):
         delete(path, shred)
         self.assertNotExists(path)
 
-    @unittest.skipIf('nt' != os.name, 'skipping on non-Windows')
+    def test_delete_read_only(self):
+        """Unit test for delete() with read-only file"""
+        for shred in (False, True):
+            fn = os.path.join(self.tempdir, 'read-only')
+            common.touch_file(fn)
+            import stat
+            os.chmod(fn, stat.S_IREAD)
+            self.assertExists(fn)
+            delete(fn, shred=shred)
+            self.assertNotExists(fn)
+
+    @common.skipUnlessWindows
+    def test_delete_hidden(self):
+        """Unit test for delete() with hidden file"""
+        for shred in (False, True):
+            fn = os.path.join(self.tempdir, 'hidden')
+            common.touch_file(fn)
+            import win32api
+            import win32con
+            win32api.SetFileAttributes(fn, win32con.FILE_ATTRIBUTE_HIDDEN)
+            self.assertExists(fn)
+            delete(fn, shred=shred)
+            self.assertNotExists(fn)
+
+    @common.skipUnlessWindows
     def test_delete_locked(self):
         """Unit test for delete() with locked file"""
         # set up
@@ -406,7 +447,30 @@ class FileUtilitiesTestCase(common.BleachbitTestCase):
             delete(filename)
             self.assertNotExists(filename)
 
-    @unittest.skipIf('nt' == os.name, 'skipping on Windows')
+    @common.skipIfWindows
+    def test_delete_mount_point(self):
+        """Unit test for deleting a mount point in use"""
+        if not common.have_root():
+            self.skipTest('not enough privileges')
+        from_dir = os.path.join(self.tempdir, 'mount_from')
+        to_dir = os.path.join(self.tempdir, 'mount_to')
+        os.mkdir(from_dir)
+        os.mkdir(to_dir)
+        args = ['mount', '--bind', from_dir, to_dir]
+        (rc, stdout, stderr) = run_external(args)
+        msg = 'error calling mount\nargs=%s\nstderr=%s' % (args, stderr)
+        self.assertEqual(rc, 0, msg)
+
+        delete(to_dir)
+
+        args = ['umount', to_dir]
+        (rc, stdout, stderr) = run_external(args)
+        msg = 'error calling umount\nargs=%s\nstderr=%s' % (args, stderr)
+        self.assertEqual(rc, 0, msg)
+
+
+
+    @common.skipIfWindows
     def test_ego_owner(self):
         """Unit test for ego_owner()"""
         self.assertEqual(ego_owner('/bin/ls'), os.getuid() == 0)
@@ -475,7 +539,6 @@ class FileUtilitiesTestCase(common.BleachbitTestCase):
         if 'nt' != os.name:
             return
         args = ['wmic',  'LogicalDisk', 'get', 'DeviceID,', 'FreeSpace']
-        from bleachbit.General import run_external
         (rc, stdout, stderr) = run_external(args)
         if rc:
             print('error calling WMIC\nargs=%s\nstderr=%s' % (args, stderr))
@@ -601,17 +664,19 @@ class FileUtilitiesTestCase(common.BleachbitTestCase):
     def test_listdir(self):
         """Unit test for listdir()"""
         if 'posix' == os.name:
-            dir1 = '/tmp'
-            dir2 = expanduser('~/.config')
+            dir1 = '/bin'
+            dir2 = expanduser('/sbin')
         if 'nt' == os.name:
             dir1 = expandvars(r'%windir%\fonts')
-            dir2 = expandvars(r'%userprofile%\desktop')
+            dir2 = expandvars(r'%windir%\logs')
         # If these directories do not exist, the test results are not valid.
         self.assertExists(dir1)
         self.assertExists(dir2)
         # Every path found in dir1 and dir2 should be found in (dir1, dir2).
         paths1 = set(listdir(dir1))
         paths2 = set(listdir(dir2))
+        self.assertGreater(len(paths1), 4)
+        self.assertGreater(len(paths2), 4)
         paths12 = set(listdir((dir1,dir2)))
         self.assertTrue(paths1 < paths12)
         self.assertTrue(paths2 < paths12)
@@ -713,7 +778,7 @@ class FileUtilitiesTestCase(common.BleachbitTestCase):
         self.assertEqual(
             set(old_whitelist), set(options.get_whitelist_paths()))
 
-    @unittest.skipUnless('posix' == os.name, 'skipping on non-POSIX platform')
+    @common.skipIfWindows
     def test_whitelisted_posix_symlink(self):
         """Symlink test for whitelisted_posix()"""
         # setup
@@ -881,7 +946,7 @@ class FileUtilitiesTestCase(common.BleachbitTestCase):
 
         delete(path)
 
-    @unittest.skipIf('nt' == os.name, 'skipping on Windows')
+    @common.skipIfWindows
     def test_OpenFiles(self):
         """Unit test for class OpenFiles"""
 
