@@ -26,6 +26,7 @@ from __future__ import absolute_import, print_function
 
 from bleachbit.FileUtilities import delete, free_space, listdir, wipe_path
 from bleachbit.General import run_external
+from tests import common
 
 import logging
 import os
@@ -124,8 +125,7 @@ def verify_cleanliness(filename):
     return clean
 
 
-@unittest.skipIf('nt' == os.name or sys.platform.startswith('freebsd'),
-                 'test_wipe() not supported on Windows or FreeBSD')
+@common.skipIfWindows
 def test_wipe_sub(n_bytes, mkfs_cmd):
     """Test FileUtilities.wipe_path"""
 
