@@ -25,12 +25,14 @@ Common code for unit tests
 from __future__ import absolute_import, print_function
 
 from bleachbit.FileUtilities import extended_path
+from bleachbit.General import sudo_mode
 
-import unittest
-import shutil
-import tempfile
+import functools
 import os
-import os.path
+import shutil
+import sys
+import tempfile
+import unittest
 
 
 class BleachbitTestCase(unittest.TestCase):
@@ -45,7 +47,8 @@ class BleachbitTestCase(unittest.TestCase):
     @classmethod
     def tearDownClass(cls):
         """remove the temporary directory"""
-        shutil.rmtree(cls.tempdir)
+        if os.path.exists(cls.tempdir):
+            shutil.rmtree(cls.tempdir)
 
     def setUp(cls):
         """Call before each test method"""
@@ -132,6 +135,34 @@ def destructive_tests(title):
     return False
 
 
+def have_root():
+    """Return true if we have root privileges on POSIX systems"""
+    return sudo_mode() or os.getuid() == 0
+
+
+def skipIfWindows(f):
+    """Skip unit test if running on Windows
+
+    Not compatible at the class level
+    """
+    @functools.wraps(f)
+    def wrapper(*args, **kwargs):
+        if sys.platform == 'win32':
+            return unittest.skipIf('win32' == sys.platform, 'running on Windows')
+        return f(*args, **kwargs)
+    return wrapper
+
+
+def skipUnlessWindows(f):
+    """Skip unit test unless running on Windows
+
+    Not compatible at the class level"""
+    @functools.wraps(f)
+    def wrapper(*args, **kwargs):
+        return unittest.skipUnless('win32' == sys.platform, 'not running on Windows')
+    return wrapper
+
+
 def touch_file(filename):
     """Create an empty file"""
     dname = os.path.dirname(filename)
